//
//  ViewController.swift
//  101-camera
//
//  Created by Jake Marsh on 10/11/15.
//  Copyright © 2015 Jake Marsh. All rights reserved.
//

import UIKit
import AVFoundation

class ViewController: UIViewController {
  var session: AVCaptureSession!
  var input: AVCaptureDeviceInput!
  var output: AVCaptureStillImageOutput!
  var previewLayer: AVCaptureVideoPreviewLayer?

  func setupSession() {
    session = AVCaptureSession()
    session.sessionPreset = AVCaptureSessionPresetPhoto

    let camera = AVCaptureDevice
      .defaultDeviceWithMediaType(AVMediaTypeVideo)

    do { input = try AVCaptureDeviceInput(device: camera) } catch { return }

    output = AVCaptureStillImageOutput()
    output.outputSettings = [ AVVideoCodecKey: AVVideoCodecJPEG ]

    guard session.canAddInput(input)
      && session.canAddOutput(output) else { return }

    session.addInput(input)
    session.addOutput(output)

    previewLayer = AVCaptureVideoPreviewLayer(session: session)

    previewLayer!.videoGravity = AVLayerVideoGravityResizeAspect
    previewLayer!.connection?.videoOrientation = .Portrait

    view.layer.addSublayer(previewLayer!)

    session.startRunning()
  }

  override func viewWillAppear(animated: Bool) {
    super.viewWillAppear(animated)

    setupSession()

    let tapGR = UITapGestureRecognizer(target: self, action: "capturePhoto:")
    tapGR.numberOfTapsRequired = 1
    view.addGestureRecognizer(tapGR)
  }

  override func viewDidLayoutSubviews() {
    super.viewDidLayoutSubviews()

    previewLayer?.frame = view.bounds
  }
  
  func presentActivityVCForImage(image: UIImage) {
    self.presentViewController(
      UIActivityViewController(activityItems: [image], applicationActivities: nil),
      animated: true,
      completion: nil
    )
  }

func capturePhoto(tapGR: UITapGestureRecognizer) {
  guard let connection = output.connectionWithMediaType(AVMediaTypeVideo) else { return }
  connection.videoOrientation = .Portrait

  output.captureStillImageAsynchronouslyFromConnection(connection) { (sampleBuffer, error) in
    guard sampleBuffer != nil && error == nil else { return }

    let imageData = AVCaptureStillImageOutput.jpegStillImageNSDataRepresentation(sampleBuffer)
    guard let image = UIImage(data: imageData) else { return }

    self.presentActivityVCForImage(image)
  }
}
}

